@@ -90,19 +90,23 @@ class EvaluationPool:
                 # compute values for each metric
                 for scoring in scorings:
                     scorer = get_scorer(scoring)
-                    if type(scorer) == sklearn.metrics._scorer._PredictScorer:
+                    is_predict_scorer = type(scorer) == sklearn.metrics._scorer._PredictScorer
+                    is_proba_scorer = type(scorer) == sklearn.metrics._scorer._ProbaScorer
+                    is_threshold_scorer = type(scorer) == sklearn.metrics._scorer._ThresholdScorer
+                    self.logger.debug(f"Now computing score for scoring function {scoring}. Predict scorer: {is_predict_scorer}, Proba sccorer: {is_proba_scorer}, Threshold scorer: {is_threshold_scorer}.")
+                    if is_predict_scorer:
                         try:
                             score = get_scorer(scoring)._score_func(y_test, y_hat)
                         except:
                             score = np.nan
-                    elif type(scorer) == sklearn.metrics._scorer._ProbaScorer:
+                    elif is_proba_scorer:
                         try:
                             score = get_scorer(scoring)._score_func(y_test, y_prob,labels=labels)
                         except:
                             score = np.nan
-                    elif type(scorer) == sklearn.metrics._scorer._ThresholdScorer:
+                    elif is_threshold_scorer:
                         try:
-                            if len(labels) == 1:
+                            if len(labels) == 2:
                                 score = get_scorer(scoring)._score_func(y_test, y_prob[:,1])
                             else:
                                 score = get_scorer(scoring)._score_func(y_test, y_prob, labels=labels)
