@@ -172,7 +172,7 @@ class NaiveAutoML:
                 components = step["components"]
             
             # find best default parametrization for this slot (depending on choice of previously configured slots)
-            pool = EvaluationPool(X, y, self.scoring, self.side_scores, logger_name = self.logger_name + ".pool")
+            pool = EvaluationPool(X, y, self.scoring, self.side_scores, logger_name = None if self.logger_name is None else self.logger_name + ".pool")
             best_score = -np.inf
             decision = None
             for comp in components:
@@ -255,7 +255,7 @@ class NaiveAutoML:
             else:
                 other_instances = [(step_name, None), ("classifier", self.standard_classifier())]
             index = 0 # it is (rather by coincidence) the first step we want to optimize
-            hpo = HPOProcess(step_name, comp, X, y, self.scoring, self.side_scores, self.execution_timeout, self.mandatory_pre_processing, other_instances, index, 1800, 1000, allow_exhaustive_search = (self.max_hpo_iterations is None), logger_name = self.logger_name + ".hpo")
+            hpo = HPOProcess(step_name, comp, X, y, self.scoring, self.side_scores, self.execution_timeout, self.mandatory_pre_processing, other_instances, index, 1800, 1000, allow_exhaustive_search = (self.max_hpo_iterations is None), logger_name =  None if self.logger_name is None else self.logger_name + ".hpo")
             hpo.best_score = components_with_score[step_name] # performance of default config
             hpo_processes[step_name] = hpo
         
@@ -299,7 +299,6 @@ class NaiveAutoML:
                     raise
                 except Exception as e:
                     self.logger.error(f"An error occurred in the HPO step: {e}")
-                    raise
                     
             round_runtimes.append(time.time() - round_start)
             for name in inactive:
